Reference
#Supported DPTs
A telegram does not transmit its DPT. Each receiving object interprets the payload using its own DPT. Object state stores the decoded value: for DPT 5.001, an entered value of 50% encodes as byte 0x80 and decodes to about 50.196%. The diagram rounds it while the inspector shows more precision.
| DPT | Name | Size | Range | Examples: value → encoded bytes → display |
|---|---|---|---|---|
1.001 |
Switch | 1 bit | 0 … 1 | 0 → 0x00 → Off ; 1 → 0x01 → On |
1.002 |
Boolean | 1 bit | 0 … 1 | 0 → 0x00 → False ; 1 → 0x01 → True |
1.003 |
Enable | 1 bit | 0 … 1 | 0 → 0x00 → Disabled ; 1 → 0x01 → Enabled |
1.005 |
Alarm | 1 bit | 0 … 1 | 0 → 0x00 → No alarm ; 1 → 0x01 → Alarm |
1.007 |
Step | 1 bit | 0 … 1 | 0 → 0x00 → Step decrease ; 1 → 0x01 → Step increase |
1.008 |
Up/Down | 1 bit | 0 … 1 | 0 → 0x00 → Up ; 1 → 0x01 → Down |
1.009 |
Open/Closed | 1 bit | 0 … 1 | 0 → 0x00 → Open ; 1 → 0x01 → Closed |
1.010 |
Start/Stop | 1 bit | 0 … 1 | 0 → 0x00 → Stop ; 1 → 0x01 → Start |
1.011 |
State | 1 bit | 0 … 1 | 0 → 0x00 → Inactive ; 1 → 0x01 → Active |
1.012 |
Invert | 1 bit | 0 … 1 | 0 → 0x00 → Not inverted ; 1 → 0x01 → Inverted |
1.017 |
Trigger | 1 bit | 0 … 1 | 0 → 0x00 → Triggered ; 1 → 0x01 → Triggered |
1.018 |
Occupation | 1 bit | 0 … 1 | 0 → 0x00 → Vacant ; 1 → 0x01 → Occupied |
1.019 |
Window/Door | 1 bit | 0 … 1 | 0 → 0x00 → Closed ; 1 → 0x01 → Open |
1.100 |
Heating/Cooling | 1 bit | 0 … 1 | 0 → 0x00 → Cooling ; 1 → 0x01 → Heating |
2.001 |
Priority control | 2 bits | 0 … 3 | 0 → 0x00 → No forcing ; 2 → 0x02 → Forced off ; 3 → 0x03 → Forced on |
3.007 |
Relative dimming | 4 bits | 0 … 15 | 0 → 0x00 → Stop dimming ; 15 → 0x0F → Increase by 1.6 % |
5.001 |
Percentage | 1 byte | 0 … 100 | 0 → 0x00 → 0 % ; 50 → 0x80 → 50 % ; 100 → 0xFF → 100 % |
5.004 |
Percentage (0–255) | 1 byte | 0 … 255 | 0 → 0x00 → 0 % ; 100 → 0x64 → 100 % ; 255 → 0xFF → 255 % |
5.010 |
Counter | 1 byte | 0 … 255 | 0 → 0x00 → 0 ; 255 → 0xFF → 255 |
7.600 |
Colour temperature | 2 bytes | 0 … 65535 | 2700 → 0x0A8C → 2700 K ; 6500 → 0x1964 → 6500 K |
9.001 |
Temperature | 2 bytes | -273 … 670433.28 | 21 → 0x0C1A → 21.0 °C ; -5.5 → 0x85DA → -5.5 °C ; 45.2 → 0x146A → 45.2 °C |
9.002 |
Temperature difference | 2 bytes | -671088.64 … 670433.28 | -2 → 0x8738 → -2.0 K ; 0.5 → 0x0032 → +0.5 K |
9.004 |
Lux | 2 bytes | 0 … 670433.28 | 350 → 0x2C46 → 350 lx ; 42000 → 0x6401 → 41,984 lx |
9.005 |
Wind speed | 2 bytes | 0 … 670433.28 | 3.5 → 0x015E → 3.5 m/s ; 14.2 → 0x058C → 14.2 m/s |
9.007 |
Humidity | 2 bytes | 0 … 670433.28 | 45 → 0x1465 → 45.0 % ; 72.5 → 0x1715 → 72.52 % |
9.008 |
Air quality | 2 bytes | 0 … 670433.28 | 650 → 0x2FEF → 650 ppm ; 1400 → 0x3C46 → 1,400 ppm |
9.024 |
Power (kW) | 2 bytes | -671088.64 … 670433.28 | 0.06 → 0x0006 → 0.06 kW ; 3.5 → 0x015E → 3.5 kW |
9.028 |
Wind speed (km/h) | 2 bytes | 0 … 670433.28 | 12.6 → 0x04EC → 12.6 km/h ; 51.1 → 0x14FE → 51.12 km/h |
10.001 |
Time of day | 3 bytes | 0 … 691199 (00:00:00 … Sun 23:59:59) | 114900 → 0x273700 → Mon 07:55:00 ; 81000 → 0x161E00 → 22:30:00 |
11.001 |
Date | 3 bytes | 19900101 … 20891231 (1990-01-01 … 2089-12-31) | 20260928 → 0x1C091A → 2026-09-28 ; 19991231 → 0x1F0C63 → 1999-12-31 |
13.010 |
Active energy | 4 bytes | -2147483648 … 2147483647 | 0 → 0x00000000 → 0 Wh ; 12500 → 0x000030D4 → 12,500 Wh |
13.013 |
Active energy (kWh) | 4 bytes | -2147483648 … 2147483647 | 0 → 0x00000000 → 0 kWh ; 4210 → 0x00001072 → 4,210 kWh |
14.056 |
Power | 4 bytes | -3.4e+38 … 3.4e+38 | 60 → 0x42700000 → 60 W ; 1250.5 → 0x449C5000 → 1,250.5 W |
17.001 |
Scene number | 1 byte | 0 … 63 | 0 → 0x00 → Scene 1 ; 63 → 0x3F → Scene 64 |
20.102 |
HVAC mode | 1 byte | 0 … 4 | 1 → 0x01 → Comfort ; 3 → 0x03 → Economy ; 4 → 0x04 → Protection |
Values of 1, 2, or 4 bits occupy the low bits of the APCI byte. Longer values follow it as 1 to 4 additional payload bytes, as shown in the Size column; the frame length grows accordingly.
Other standard DPTs can be used on the objects of passive and display devices, which show them without simulating them: see passive devices.
In JSON, a time of day (10.001) is a number of seconds counted from 00:00 on the day given by the week day: 0 means no day, 86400 × n + seconds means day n (1 = Monday, 7 = Sunday). A date (11.001) is written as the number YYYYMMDD.